@@ -114,6 +114,12 @@
 }
 
 
+- _resultGraphDeath_
+{
+  [resultGraph drop];
+  resultGraph = nil;
+  return self;
+}
 
 - buildObjects
 {
@@ -127,7 +133,7 @@
   // the `bug.scm' datafile.
 
   if ((parameterManager = 
-       [lispAppArchiver getWithZone: self object: "parameterManager"]) == nil)
+       [lispAppArchiver getWithZone: self key: "parameterManager"]) == nil)
     raiseEvent(InvalidOperation,
                "Can't find the parameterManager parameters");
   
@@ -145,6 +151,9 @@
   [resultGraph setAxisLabelsX: "Model #" Y: "Run Time"];
   resultGraph = [resultGraph createEnd] ;
 
+  [resultGraph enableDestroyNotification: self
+               notificationMethod: @selector (_resultGraphDeath_)];
+
   // Create a sequence to track model run times.
   // Since we keep changing models, we feed from our own method
   // "getModelTime" which will probe the correct instance of 
@@ -363,7 +372,8 @@
 
 - showStats
 {
-  [resultGraph step];			// step the result Graph
+  if (resultGraph)
+    [resultGraph step];			// step the result Graph
   return self;
 }
 
